@@ -254,6 +254,22 @@ eel_gconf_get_string_list (const char *key)
 	return slist;
 }
 
+void
+eel_gconf_unset (const char *key)
+{
+	GConfClient *client;
+	GError *error;
+	
+	g_return_if_fail (key != NULL);
+	
+	client = eel_gconf_client_get_global ();
+	g_return_if_fail (client != NULL);
+	
+	error = NULL;
+	gconf_client_unset (client, key, &error);
+	eel_gconf_handle_error (&error);
+}
+
 gboolean
 eel_gconf_is_default (const char *key)
 {
@@ -435,22 +451,18 @@ simple_value_is_equal (const GConfValue *a,
 	case GCONF_VALUE_STRING:
 		return eel_str_is_equal (gconf_value_get_string (a),
 					 gconf_value_get_string (b));
-		break;
 
 	case GCONF_VALUE_INT:
 		return gconf_value_get_int (a) ==
 			gconf_value_get_int (b);
-		break;
 
 	case GCONF_VALUE_FLOAT:
 		return gconf_value_get_float (a) ==
 			gconf_value_get_float (b);
-		break;
 
 	case GCONF_VALUE_BOOL:
 		return gconf_value_get_bool (a) ==
 			gconf_value_get_bool (b);
-		break;
 	default:
 		g_assert_not_reached ();
 	}
