@@ -37,6 +37,7 @@
 #include <gtk/gtksignal.h>
 #include <gtk/gtkstock.h>
 #include <libgnomeui/gnome-uidefs.h>
+#include <libgnomeui/gnome-authentication-manager.h>
 
 #define TIMED_WAIT_STANDARD_DURATION 2000
 #define TIMED_WAIT_MIN_TIME_UP 3000
@@ -119,7 +120,7 @@ static void
 timed_wait_free (TimedWait *wait)
 {
 	guint delayed_close_handler_id;
-	guint32 time_up;
+	guint64 time_up;
 
 	g_assert (g_hash_table_lookup (timed_wait_hash_table, wait) != NULL);
 
@@ -201,6 +202,10 @@ timed_wait_callback (gpointer callback_data)
 
 	wait = callback_data;
 
+	if (gnome_authentication_manager_dialog_is_visible ()) {
+		return TRUE;
+	}
+	
 	/* Put up the timed wait window. */
 	button = wait->cancel_callback != NULL ? GTK_STOCK_CANCEL : GTK_STOCK_OK;
 	dialog = GTK_DIALOG (eel_alert_dialog_new (NULL,
@@ -556,7 +561,7 @@ eel_show_yes_no_dialog (const char *primary_text,
 			const char *no_label,
 			GtkWindow *parent)
 {
-	GtkDialog *dialog = 0;
+	GtkDialog *dialog = NULL;
 	dialog = eel_create_question_dialog (primary_text,
 					     secondary_text,
 					     dialog_title == NULL ? _("Question") : dialog_title,
